Installation
============

Mercantile is easy to install with pip

.. code-block:: console

    pip install mercantile

or with conda.

.. code-block:: console

    conda install -c conda-forge mercantile

